@@ -4,13 +4,17 @@ macro_rules! impl_tuple {
     ($($T:ident),*) => {
         impl<$($T : StableHash,)*> StableHash for ($($T,)*) {
             #[allow(non_snake_case)]
-            fn stable_hash<H: StableHasher>(&self, mut sequence_number: H::Seq, state: &mut H) {
+            #[allow(unused_assignments)]
+            fn stable_hash<H: StableHasher>(&self, field_address: H::Addr, state: &mut H) {
                 profile_method!(stable_hash);
 
                 let ($($T,)*) = self;
 
+                let mut i = 0;
+
                 $(
-                    $T.stable_hash(sequence_number.next_child(), state);
+                    $T.stable_hash(field_address.child(i), state);
+                    i += 1;
                 )*
             }
         }
