@@ -1,5 +1,5 @@
 pub(crate) use crate::utils::*;
 pub(crate) use firestorm::{profile_fn, profile_method};
 
-pub use crate::sequence_number::SequenceNumber;
+pub use crate::FieldAddress;
 pub use crate::{StableHash, StableHasher};
